@@ -1257,7 +1257,8 @@ static int add_partition(struct fdisk_context *cxt, size_t n,
 		if (start >= temp + fdisk_get_units_per_sector(cxt)
 		    && read) {
 			if (!pa || !pa->start_follow_default)
-				fdisk_info(cxt, _("Sector %llu is already allocated."), temp);
+				fdisk_info(cxt, _("Sector %ju is already allocated."),
+						(uintmax_t) temp);
 			temp = start;
 			read = 0;
 			if (pa && fdisk_partition_has_start(pa))
@@ -1513,12 +1514,13 @@ static void check(struct fdisk_context *cxt, size_t n,
 				   "maximum %d"), n, h + 1, cxt->geom.heads);
 	if (real_s >= cxt->geom.sectors)
 		fdisk_warnx(cxt, _("Partition %zu: sector %d greater than "
-				   "maximum %llu"), n, s, cxt->geom.sectors);
+				   "maximum %ju"), n, s,
+				(uintmax_t) cxt->geom.sectors);
 	if (real_c >= cxt->geom.cylinders)
 		fdisk_warnx(cxt, _("Partition %zu: cylinder %d greater than "
-				   "maximum %llu"),
+				   "maximum %ju"),
 				n, real_c + 1,
-				cxt->geom.cylinders);
+				(uintmax_t) cxt->geom.cylinders);
 
 	if (cxt->geom.cylinders <= 1024 && start != total)
 		fdisk_warnx(cxt, _("Partition %zu: previous sectors %u "
@@ -1704,11 +1706,11 @@ static int dos_verify_disklabel(struct fdisk_context *cxt)
 	if (!nerrors) {
 		fdisk_info(cxt, _("No errors detected."));
 		if (total > n_sectors)
-			fdisk_info(cxt, _("Total allocated sectors %llu greater "
-				"than the maximum %llu."), total, n_sectors);
+			fdisk_info(cxt, _("Total allocated sectors %ju greater "
+				"than the maximum %ju."), (uintmax_t) total, (uintmax_t) n_sectors);
 		else if (total < n_sectors)
-			fdisk_info(cxt, _("Remaining %lld unallocated %ld-byte "
-				"sectors."), n_sectors - total, cxt->sector_size);
+			fdisk_info(cxt, _("Remaining %ju unallocated %ld-byte "
+				"sectors."), (uintmax_t) n_sectors - total, cxt->sector_size);
 	} else
 		fdisk_warnx(cxt,
 			P_("%d error detected.", "%d errors detected.", nerrors),
@@ -1873,12 +1875,12 @@ static int dos_add_partition(struct fdisk_context *cxt,
 					msg =  _("All space for primary partitions is in use.");
 
 				if (pa && fdisk_partition_has_start(pa)) {
-					fdisk_warnx(cxt, msg);
+					fdisk_warnx(cxt, "%s", msg);
 					return -EINVAL;
 				}
-				fdisk_info(cxt, msg);
+				fdisk_info(cxt, "%s", msg);
 			}
-			DBG(LABEL, ul_debug("DOS: tring logical"));
+			DBG(LABEL, ul_debug("DOS: trying logical"));
 			rc = add_logical(cxt, pa, &res);
 		} else {
 			if (free_primary)
@@ -2440,10 +2442,8 @@ static int dos_reorder(struct fdisk_context *cxt)
 	struct pte *pei, *pek;
 	size_t i,k;
 
-	if (!wrong_p_order(cxt, NULL)) {
-		fdisk_info(cxt, _("Nothing to do. Ordering is correct already."));
+	if (!wrong_p_order(cxt, NULL))
 		return 1;
-	}
 
 	while ((i = wrong_p_order(cxt, &k)) != 0 && i < 4) {
 		/* partition i should have come earlier, move it */
@@ -2680,7 +2680,8 @@ struct fdisk_label *fdisk_new_dos_label(struct fdisk_context *cxt __attribute__
 	lb->geom_max.heads = 255;
 	lb->geom_max.cylinders = 1048576;
 
-	return lb;
+	/* return calloc() result to keep static anaylizers happy */
+	return (struct fdisk_label *) dos;
 }
 
 /**
